==> custom_pages-v1.12.8.zip: custom_pages/messages/it/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Aggiungi</strong> {templateName} oggetto',
    '<strong>Custom</strong> Pages' => 'Pagine <strong>Personalizzate</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Modifica</strong> snippet',
    'Add' => 'Aggiungi',
    'Add a file icon before the title' => 'Aggiungi un\'icona prima del titolo',
    'Adds plain HTML content to your site.' => 'Aggiunge contenuto HTML al tuo sito.',
    'Advanced' => 'Avanzate',
    'Allows the user to manage custom pages.' => 'Consente all\'utente di gestire pagine personalizzate.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permette di aggiungere pagine (markdown, iframe o link) al menu dello spazio',
    'Allows you to add content in MarkDown syntax.' => 'Ti permette di aggiungere contenuti nella sintassi MarkDown.',
    'Alternate text' => 'Testo alternativo',
    'Always' => 'Sempre',
    'Always make a backup of your view files outside of your production environment!' => 'Effettua sempre un backup dei tuoi view file al di fuori del tuo ambiente di produzione!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Una selezione modello vuota consentirà tutti i modelli di contenitore per questo contenitore.',
    'Back' => 'Indietro',
    'Back to dashboard' => 'Torna alla bacheca',
    'Back to overview' => 'Torna alla panoramica',
    'Back to space' => 'Torna allo spazio',
    'Can manage custom pages' => 'Può gestire pagine personalizzate',
    'Category' => 'Categoria',
    'Configuration' => 'Configurazione',
    'Content' => 'Contenuto',
    'Create' => 'Crea',
    'Css Class' => 'Classe CSS',
    'Custom' => 'Personalizzato',
    'Custom Pages' => 'Pagine personalizzate',
    'Custom pages' => 'Pagine personalizzate',
    'Dashboard' => 'Bacheca',
    'Default' => 'Predefinito',
    'Default Content' => 'Contenuto predefinito',
    'Delete' => 'Cancella',
    'Edit' => 'Modifica',
    'Edit Page' => 'Modifica pagina',
    'Empty' => 'Vuoto',
    'File' => 'File',
    'Footer menu' => 'Menu fondo pagina',
    'General' => 'Generale',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Icona',
    'Iframe' => 'IFrame',
    'Insert' => 'Inserisci',
    'Invalid request data!' => 'Richiesta non valida!',
    'Invalid template selection!' => 'Selezione template non valida!',
    'Invalid type selection' => 'Selezione tipo invalida',
    'Invalid view file selection!' => 'Selezione visualizzazione non valida!',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Impostazioni del menu',
    'Navigation' => 'Navigazione',
    'On this page you can configure general settings of your custom pages.' => 'In questa pagina puoi configurare le impostazioni generali delle tue pagine personalizzate.',
    'Overview' => 'Panoramica',
    'PHP' => 'PHP',
    'Page' => 'Pagina',
    'Pages' => 'Pagine',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Scegli uno dei seguenti tipi di contenuto. Il tipo di contenuto definisce il modo in cui il contenuto viene incorporato nel tuo sito.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Si prega di tenere presente che le pagine basate su php sono vulnerabili ai problemi di sicurezza, specialmente quando si gestisce l\'input dell\'utente. Per ulteriori informazioni, consulta le <a href="{url}"> Best practice sulla sicurezza di Yii </a>.',
    'Public' => 'Pubblico',
    'Reset' => 'Reset',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Seleziona questa impostazione solo per i nodi di testo visibili. Deseleziona questa impostazione nel caso in cui questo elemento venga utilizzato, ad esempio, come valore dell\'attributo HTML.',
    'Settings' => 'Impostazioni',
    'Show additional file information (size)' => 'Mostra informazioni file aggiuntive (dimensioni)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Snippet',
    'Sort Order' => 'Ordinamento',
    'Source' => 'Sorgente',
    'Space' => 'Spazio',
    'Space Members only' => 'Solo membri dello spazio',
    'Space Navigation' => 'Naviga nello space',
    'Spaces' => 'Space',
    'Stream' => 'Stream',
    'Stream options' => 'Opzioni dello stream',
    'Style' => 'Stile',
    'Style Class' => 'Stile Class',
    'Submit' => 'Invia',
    'Target Url' => 'Url di destinazione',
    'Template' => 'Modello',
    'Template Layout' => 'Layout template',
    'Templates' => 'Modelli',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'I modelli permettono di definire parti di pagine combinabili con funzionalità in linea',
    'This container does not allow any further items!' => 'Questo contenitore non permette altri oggetti!',
    'Title' => 'Titolo',
    'Top Navigation' => 'Top Menu',
    'Topics' => 'Argomenti',
    'Type' => 'Tipo',
    'Upload image' => 'Carica immagine',
    'User Account Menu (Settings)' => 'Menu impostazione per utenti',
    'Visibility' => 'Visibilità',
    'Will embed the result of a given url as an iframe element.' => 'Incorporerà il risultato di un determinato URL come elemento iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Reindirizzerà le richieste a un determinato URL (relativo o assoluto).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Con le pagine basate su PHP è possibile creare pagine personalizzate tramite i view file nel proprio file system. Si prega di verificare la configurazione del modulo per ulteriori informazioni.',
    'Without adding to navigation (Direct link)' => 'Senza aggiungere al menu (collegamento diretto)',
    'You are not allowed to delete default content!' => 'Non sei abilitato a cancellare il contenuto predefinito!',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Authors' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/it/base.php <==
<?php

return [
    '<strong>Add</strong> {templateName} item' => '<strong>Aggiungi</strong> {templateName} oggetto',
    '<strong>Custom</strong> Pages' => 'Pagine <strong>Personalizzate</strong>',
    '<strong>Edit</strong> snippet' => '<strong>Modifica</strong> snippet',
    'Add' => 'Aggiungi',
    'Add a file icon before the title' => 'Aggiungi un\'icona prima del titolo',
    'Adds plain HTML content to your site.' => 'Aggiunge contenuto HTML al tuo sito.',
    'Advanced' => 'Avanzate',
    'Allows the user to manage custom pages.' => 'Consente all\'utente di gestire pagine personalizzate.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'Permette di aggiungere pagine (markdown, iframe o link) al menu dello spazio',
    'Allows you to add content in MarkDown syntax.' => 'Ti permette di aggiungere contenuti nella sintassi MarkDown.',
    'Alternate text' => 'Testo alternativo',
    'Always' => 'Sempre',
    'Always make a backup of your view files outside of your production environment!' => 'Effettua sempre un backup dei tuoi view file al di fuori del tuo ambiente di produzione!',
    'An empty allowed template selection will allow all container templates for this container.' => 'Una selezione modello vuota consentirà tutti i modelli di contenitore per questo contenitore.',
    'Back' => 'Indietro',
    'Back to dashboard' => 'Torna alla bacheca',
    'Back to overview' => 'Torna alla panoramica',
    'Back to space' => 'Torna allo spazio',
    'Can manage custom pages' => 'Può gestire pagine personalizzate',
    'Category' => 'Categoria',
    'Configuration' => 'Configurazione',
    'Content' => 'Contenuto',
    'Create' => 'Crea',
    'Css Class' => 'Classe CSS',
    'Custom' => 'Personalizzato',
    'Custom Pages' => 'Pagine personalizzate',
    'Custom pages' => 'Pagine personalizzate',
    'Dashboard' => 'Bacheca',
    'Default' => 'Predefinito',
    'Default Content' => 'Contenuto predefinito',
    'Delete' => 'Cancella',
    'Edit' => 'Modifica',
    'Edit Page' => 'Modifica pagina',
    'Empty' => 'Vuoto',
    'File' => 'File',
    'Footer menu' => 'Menu fondo pagina',
    'General' => 'Generale',
    'Html' => 'Html',
    'ID' => 'ID',
    'Icon' => 'Icona',
    'Iframe' => 'IFrame',
    'Insert' => 'Inserisci',
    'Invalid request data!' => 'Richiesta non valida!',
    'Invalid template selection!' => 'Selezione template non valida!',
    'Invalid type selection' => 'Selezione tipo invalida',
    'Invalid view file selection!' => 'Selezione visualizzazione non valida!',
    'Link' => 'Link',
    'MarkDown' => 'MarkDown',
    'Menu settings' => 'Impostazioni del menu',
    'Navigation' => 'Navigazione',
    'On this page you can configure general settings of your custom pages.' => 'In questa pagina puoi configurare le impostazioni generali delle tue pagine personalizzate.',
    'Overview' => 'Panoramica',
    'PHP' => 'PHP',
    'Page' => 'Pagina',
    'Pages' => 'Pagine',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => 'Scegli uno dei seguenti tipi di contenuto. Il tipo di contenuto definisce il modo in cui il contenuto viene incorporato nel tuo sito.',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => 'Si prega di tenere presente che le pagine basate su php sono vulnerabili ai problemi di sicurezza, specialmente quando si gestisce l\'input dell\'utente. Per ulteriori informazioni, consulta le <a href="{url}"> Best practice sulla sicurezza di Yii </a>.',
    'Public' => 'Pubblico',
    'Reset' => 'Reset',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => 'Seleziona questa impostazione solo per i nodi di testo visibili. Deseleziona questa impostazione nel caso in cui questo elemento venga utilizzato, ad esempio, come valore dell\'attributo HTML.',
    'Settings' => 'Impostazioni',
    'Show additional file information (size)' => 'Mostra informazioni file aggiuntive (dimensioni)',
    'Snippet' => 'Snippet',
    'Snippets' => 'Snippet',
    'Sort Order' => 'Ordinamento',
    'Source' => 'Sorgente',
    'Space' => 'Spazio',
    'Space Members only' => 'Solo membri dello spazio',
    'Space Navigation' => 'Naviga nello space',
    'Spaces' => 'Space',
    'Stream' => 'Stream',
    'Stream options' => 'Opzioni dello stream',
    'Style' => 'Stile',
    'Style Class' => 'Stile Class',
    'Submit' => 'Invia',
    'Target Url' => 'Url di destinazione',
    'Template' => 'Modello',
    'Template Layout' => 'Layout template',
    'Templates' => 'Modelli',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => 'I modelli permettono di definire parti di pagine combinabili con funzionalità in linea',
    'This container does not allow any further items!' => 'Questo contenitore non permette altri oggetti!',
    'Title' => 'Titolo',
    'Top Navigation' => 'Top Menu',
    'Topics' => 'Argomenti',
    'Type' => 'Tipo',
    'Upload image' => 'Carica immagine',
    'User Account Menu (Settings)' => 'Menu impostazione per utenti',
    'Visibility' => 'Visibilità',
    'Will embed the result of a given url as an iframe element.' => 'Incorporerà il risultato di un determinato URL come elemento iframe.',
    'Will redirect requests to a given (relative or absolute) url.' => 'Reindirizzerà le richieste a un determinato URL (relativo o assoluto).',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => 'Con le pagine basate su PHP è possibile creare pagine personalizzate tramite i view file nel proprio file system. Si prega di verificare la configurazione del modulo per ulteriori informazioni.',
    'Without adding to navigation (Direct link)' => 'Senza aggiungere al menu (collegamento diretto)',
    'You are not allowed to delete default content!' => 'Non sei abilitato a cancellare il contenuto predefinito!',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Cannot delete!' => '',
    'Container' => '',
    'Content filters' => '',
    'Deleted.' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Page' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'Non-Logged-In Users' => '',
    'Page Content' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Sorting' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Usage' => '',
    'Wrap this HTML page with white panel' => '',
];
